@@ -74,7 +74,7 @@
 #' @export
 
 stress_VaR_ES <- function(x, alpha, q_ratio = NULL,
-                          s_ratio = NULL, q = NULL, s = NULL, k = 1, normalise = FALSE){
+                          s_ratio = NULL, q = NULL, s = NULL, k = 1, normalise = FALSE, names = NULL, log = FALSE){
 
   if (is.SWIM(x)) x_data <- get_data(x) else x_data <- as.matrix(x)
   if (anyNA(x_data)) warning("x contains NA")
@@ -135,18 +135,31 @@ stress_VaR_ES <- function(x, alpha, q_ratio = NULL,
   constr <- cbind(alpha, "q"= VaR_achieved, s)
   new_weights <- apply(X = constr, MARGIN = 1, FUN = .rn_VaR_ES, y = x_data[, k], normalise = normalise)
   if (is.null(colnames(x_data))) colnames(x_data) <-  paste("X", as.character(1:dim(x_data)[2]), sep = "")
-  names(new_weights) <- paste(rep("stress", max_length), 1:max_length)
+  
+  # Name stresses
+  if (is.null(names)) {
+    temp <- paste(rep("stress", max_length), 1:max_length)
+  } else {
+    temp <- names
+  }
+  if (length(temp) != max_length) stop("length of names are not the same as the number of models")
+  names(new_weights) <- temp
 
   type <- rep(list("VaR ES"), length.out = max_length)
   constr1 <- cbind("k" = rep(k, length.out = max_length), constr)
   constr_ES <- list()
   for(s in 1:max_length){
     temp_list <- list(as.list(constr1[s, ]))
-    names(temp_list) <- paste("stress", s)
+    names(temp_list) <- temp[s]
     constr_ES <- c(constr_ES, temp_list)
   }
   my_list <- SWIM("x" = x_data, "new_weights" = new_weights, "type" = type, "specs" = constr_ES)
   if (is.SWIM(x)) my_list <- merge(x, my_list)
+  
+  if (log) {
+    summary_weights(my_list)
+  }
+  
   return(my_list)
 }
 
